.. Master file automatically created by doconce sphinx_dir


A Document for Testing DocOnce
==============================

Contents:

.. toctree::
   :maxdepth: 2

   ._testdoc000
   ._testdoc001
   ._testdoc002
   ._testdoc003
   ._testdoc004
   ._testdoc005
   ._testdoc006
   ._testdoc007
   ._testdoc008
   ._testdoc009
   ._testdoc010
Index
=====

* :ref:`genindex`
